@@ -5,9 +5,7 @@ from .utils import import_from_string
 
 
 @click.command()
-@click.argument(
-    "app", type=str, help="Path to a Forerunner App. For example: my_project.main:app"
-)
+@click.argument("app", type=str)
 def main(app: str):
     loaded_app = import_from_string(app)
     if not isinstance(loaded_app, App):
